@@ -1,13 +1,13 @@
 ;;; ediff.el --- a comprehensive visual interface to diff & patch
 
-;; Copyright (C) 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
+;; Copyright (C) 1994, 95, 96, 97, 98, 99, 2000 Free Software Foundation, Inc.
 
 ;; Author: Michael Kifer <kifer@cs.sunysb.edu>
 ;; Created: February 2, 1994
 ;; Keywords: comparing, merging, patching, version control.
 
-(defconst ediff-version "2.72" "The current version of Ediff")
-(defconst ediff-date "December 27, 1998" "Date of last update")  
+(defconst ediff-version "2.74" "The current version of Ediff")
+(defconst ediff-date "October 31, 1999" "Date of last update")  
 
 
 ;; This file is part of GNU Emacs.
@@ -300,7 +300,7 @@
 	     (setq file
 		   (ediff-make-temp-file
 		    (current-buffer) temp-file-name-prefix))
-	     (set hooks-var (cons (` (lambda () (delete-file (, file))))
+	     (set hooks-var (cons `(lambda () (delete-file ,file))
 				  (symbol-value hooks-var))))
 	    ;; file processed via auto-mode-alist, a la uncompress.el
 	    ((not (equal (file-truename file)
@@ -308,7 +308,7 @@
 	     (setq file
 		   (ediff-make-temp-file
 		    (current-buffer) temp-file-name-prefix))
-	     (set hooks-var (cons (` (lambda () (delete-file (, file))))
+	     (set hooks-var (cons `(lambda () (delete-file ,file))
 				  (symbol-value hooks-var))))
 	    (t ;; plain file---just check that the file matches the buffer
 	     (ediff-verify-file-buffer))))
@@ -430,11 +430,10 @@
 		 (get-buffer buf-B) file-B
 		 (if buf-C-is-alive (get-buffer buf-C))
 		 file-C
-		 (cons (` (lambda ()
-			    (delete-file (, file-A))
-			    (delete-file (, file-B))
-			    (if (stringp (, file-C)) (delete-file (, file-C)))
-			    ))
+		 (cons `(lambda ()
+			  (delete-file ,file-A)
+			  (delete-file ,file-B)
+			  (if (stringp ,file-C) (delete-file ,file-C)))
 		       startup-hooks)
 		 (list (cons 'ediff-job-name job-name))
 		 merge-buffer-file)))
@@ -699,11 +698,11 @@ names.  Only the files that are under revision control are taken into account."
     (setq startup-hooks
 	  ;; this sets various vars in the meta buffer inside
 	  ;; ediff-prepare-meta-buffer
-	  (cons (` (lambda ()
-		     ;; tell what to do if the user clicks on a session record
-		     (setq ediff-session-action-function (quote (, action)))
-		     ;; set ediff-dir-difference-list 
-		     (setq ediff-dir-difference-list (quote (, diffs)))))
+	  (cons `(lambda ()
+		   ;; tell what to do if the user clicks on a session record
+		   (setq ediff-session-action-function (quote ,action))
+		   ;; set ediff-dir-difference-list 
+		   (setq ediff-dir-difference-list (quote ,diffs)))
 		startup-hooks))
     (setq meta-buf (ediff-prepare-meta-buffer 
 		    'ediff-filegroup-action
@@ -751,10 +750,9 @@ names.  Only the files that are under revision control are taken into account."
     (setq startup-hooks
 	  ;; this sets various vars in the meta buffer inside
 	  ;; ediff-prepare-meta-buffer
-	  (cons (` (lambda ()
-		     ;; tell what to do if the user clicks on a session record
-		     (setq ediff-session-action-function (quote (, action)))
-		     ))
+	  (cons `(lambda ()
+		   ;; tell what to do if the user clicks on a session record
+		   (setq ediff-session-action-function (quote ,action)))
 		startup-hooks))
     (setq meta-buf (ediff-prepare-meta-buffer 
 		    'ediff-filegroup-action
@@ -963,9 +961,9 @@ Continue anyway? (y/n) "))
     (ediff-setup buffer-A file-A
 		 buffer-B file-B
 		 nil nil	    ; buffer & file C
-		 (cons (` (lambda ()
-			    (delete-file (, file-A))
-			    (delete-file (, file-B))))
+		 (cons `(lambda ()
+			    (delete-file ,file-A)
+			    (delete-file ,file-B))
 		       startup-hooks)
 		 (append
 		  (list (cons 'ediff-word-mode  word-mode)
@@ -1199,7 +1197,7 @@ buffer."
 	  ancestor-rev
 	  (read-string
 	   (format
-	    "Ancestor version (default: %s): "
+	    "Ancestor version (default: %s's base revision): "
 	    (if (stringp file)
 		(file-name-nondirectory file) "current buffer"))))
     (ediff-load-version-control)
@@ -1223,13 +1221,18 @@ file and then run `run-ediff-from-cvs-buffer'."
 ;;; Apply patch
 
 ;;;###autoload
-(defun ediff-patch-file ()
-  "Run Ediff by patching SOURCE-FILENAME."
-  ;; This now returns the control buffer
-  (interactive)
-  (let (source-dir source-file patch-buf)
+(defun ediff-patch-file (&optional arg patch-buf)
+  "Run Ediff by patching SOURCE-FILENAME.
+If optional PATCH-BUF is given, use the patch in that buffer
+and don't ask the user.
+If prefix argument, then: if even argument, assume that the patch is in a
+buffer. If odd -- assume it is in a file."
+  (interactive "P")
+  (let (source-dir source-file)
     (require 'ediff-ptch)
-    (setq patch-buf (ediff-get-patch-buffer))
+    (setq patch-buf
+	  (ediff-get-patch-buffer
+	   (if arg (prefix-numeric-value arg)) patch-buf))
     (setq source-dir (cond (ediff-use-last-dir ediff-last-dir-patch)
 			   ((and (not ediff-patch-default-directory)
 				 (buffer-file-name patch-buf))
@@ -1239,25 +1242,26 @@ file and then run `run-ediff-from-cvs-buffer'."
 			   (t default-directory)))
     (setq source-file
 	  ;; the default is the directory, not the visited file name
-	  (ediff-read-file-name 
-	   "Which file to patch? " source-dir (ediff-get-default-file-name)))
+	  (read-file-name 
+	   "File to patch (directory, if multifile patch): "
+	   source-dir (ediff-get-default-file-name)))
     (ediff-dispatch-file-patching-job patch-buf source-file)))
 
 ;;;###autoload
-(defun ediff-patch-buffer ()
+(defun ediff-patch-buffer (&optional arg patch-buf)
   "Run Ediff by patching BUFFER-NAME."
-  (interactive)
-  (let (patch-buf)
-    (require 'ediff-ptch)
-    (setq patch-buf (ediff-get-patch-buffer))
-    (ediff-patch-buffer-internal
-     patch-buf
-     (read-buffer "Which buffer to patch? "
-		  (cond ((eq patch-buf (current-buffer))
-			 (ediff-other-buffer (current-buffer)))
-			(t (current-buffer)))
-		  'must-match))))
+  (interactive "P")
+  (require 'ediff-ptch)
+  (setq patch-buf
+	(ediff-get-patch-buffer
+	 (if arg (prefix-numeric-value arg)) patch-buf))
+  (ediff-patch-buffer-internal
+   patch-buf
+   (read-buffer
+    "Which buffer to patch? "
+    (ediff-prompt-for-patch-buffer))))
   
+
 ;;;###autoload
 (defalias 'epatch 'ediff-patch-file)
 ;;;###autoload
